package cc.fascinated.wildaddons.addon;

import cc.fascinated.wildaddons.event.EventListener;
import cc.fascinated.wildaddons.event.EventManager;
import lombok.Getter;

@Getter
public abstract class Addon implements EventListener {

    public enum Category {
        CHAT,
        UI
    }
    private final String name;
    private final String description;
    private final Category category;

    private boolean enabled;

    public Addon(String name, String description, Category category) {
        this.name = name;
        this.description = description;
        this.category = category;
        this.enabled = true;

        EventManager.registerListener(this);
        this.onEnable();
    }

    /**
     * Toggles this addon on or off.
     */
    public void toggle() {
        this.enabled = !this.enabled;

        if (this.enabled) {
            this.onDisable();
        } else {
            this.onEnable();
        }
    }

    /**
     * Called when this addon gets enabled.
     */
    public void onEnable() {}

    /**
     * Called when this addon gets disabled.
     */
    public void onDisable() {}
}
