package cc.fascinated.wildaddons.addon;

import java.util.HashSet;
import java.util.Set;

import cc.fascinated.wildaddons.addon.impl.chat.AutoWelcomerAddon;
import cc.fascinated.wildaddons.addon.impl.chat.ChatGameHelperAddon;
import cc.fascinated.wildaddons.addon.impl.chat.MessageFilterAddon;
import cc.fascinated.wildaddons.addon.impl.ui.OverlayAddon;

public class AddonManager {

    /**
     * The current registered addons
     */
    public static final Set<Addon> ADDONS = new HashSet<>();

    /**
     * Checks if the addon is enabled
     *
     * @param clazz the class of the addon
     * @return true if the addon is enabled, false otherwise
     */
    public static boolean isEnabled(Class<?> clazz) {
        for (Addon addon : ADDONS) {
            if (addon.getClass().equals(clazz)) {
                return addon.isEnabled();
            }
        }
        return false;
    }

    public AddonManager() {
        this.registerAddon(new AutoWelcomerAddon());
        this.registerAddon(new OverlayAddon());
        this.registerAddon(new MessageFilterAddon());
        this.registerAddon(new ChatGameHelperAddon());
    }

    /**
     * Registers an addon.
     *
     * @param addon The addon to register
     */
    public void registerAddon(Addon addon) {
        ADDONS.add(addon);
    }
}
