package cc.fascinated.wildaddons.event;

import net.minecraft.network.Packet;
import net.minecraft.text.Text;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

public interface EventListener {

    /**
     * Gets called every game tick
     *
     * @param ticksPassed the total amount of ticks passed
     */
    default void onTick(int ticksPassed) {}

    /**
     * Gets called when a chat message is received
     *
     * @param message the message
     * @param messageStripped the message without colors
     */
    default void onChat(String message, String messageStripped, CallbackInfo ci) {}

    /**
     * Gets called when the client receives a packet.
     *
     * @param packet the packet
     */
    default void onPacketReceive(Packet<?> packet) {}

    /**
     * Gets called when the client sends a packet.
     *
     * @param packet the packet
     */
    default void onPacketSend(Packet<?> packet) {}

    /**
     * Gets called every time the tab-list updates.
     *
     * @param header the header
     * @param footer the footer
     */
    default void onTabListUpdate(Text header, Text footer) {}
}
