package cc.fascinated.wildaddons.utils;

import lombok.Getter;
import org.spongepowered.configurate.CommentedConfigurationNode;
import org.spongepowered.configurate.ConfigurateException;
import org.spongepowered.configurate.ConfigurationNode;
import org.spongepowered.configurate.hocon.HoconConfigurationLoader;
import org.spongepowered.configurate.loader.ConfigurationLoader;

import java.io.File;
import java.io.IOException;

public class Config {

    private ConfigurationLoader<CommentedConfigurationNode> configurationLoader;
    @Getter private ConfigurationNode node;

    /**
     * Creates a new configuration
     *
     * @param dirName the directory path
     * @param fileName the file name
     */
    public Config(String dirName, String fileName) {
        File dir = new File(dirName);
        if (!dir.exists()) {
            dir.mkdirs();
        }
        File file = new File(dir.getAbsolutePath() + File.separator + fileName);
        if (!file.exists()) {
            try {
                file.createNewFile();
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
        }

        configurationLoader = HoconConfigurationLoader.builder()
                .file(file)
                .emitJsonCompatible(true)
                .emitComments(true)
                .prettyPrinting(true)
                .build();
        try {
            node = configurationLoader.load();
        } catch (ConfigurateException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * Saves the config file.
     *
     * @throws ConfigurateException thrown if there was an error saving
     */
    public void save() throws ConfigurateException {
        configurationLoader.save(node);
    }
}
